
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.81'
version = '1.2.81'
full_version = '1.2.81'
git_revision = '076e03c34aeae309160e7d811e6d643e2aadf352'
release = True

if not release:
    version = full_version
    short_version += ".dev"
